..
    This file was automatically generated using `mots export`.
.. note::
    To add, remove, or update module information, see the `mots documentation <https://mots.readthedocs.io/en/latest/#adding-a-module>`_.

=======
Modules
=======


Main
~~~~


.. list-table::
    :stub-columns: 1
    :widths: 30 70

    * - Owner(s)
      -
        | `Zeid Zabaneh (zeid) <https://people.mozilla.org/s?query=zeid>`__
    * - Includes
      -
        | \*\*/\*
